@@ -74,7 +74,7 @@ def call(command, stdin=None, stdout=PIPE, env=os.environ, cwd=None, shell=False
         process = subprocess.Popen(args, stdin=PIPE, stdout=stdout, stderr=STDOUT,
                                    env=env, cwd=cwd, **kw)
         output = process.communicate(input=stdin)[0]
-        logger.log(output_log_level, output)
+        logger.log(output_log_level, output.encode('utf-8'))
         return (process.returncode, output)
     except OSError:
         e = sys.exc_info()[1]
@@ -305,7 +305,7 @@ def extract_dmg(url, target_dir, remove_common_prefix=False, overwrite=False):
         if not os.path.exists(target_dir):
             os.makedirs(target_dir)
         temp_file = os.path.join(tmpdir, "temp.dmg")
-        with open(temp_file, 'bw+') as fh:
+        with open(temp_file, 'wb+') as fh:
             fh.write(requests.get(url).content)
         call("hdiutil attach %s -mountpoint /Volumes/a/" % temp_file)
         for f in os.listdir("/Volumes/a/"):
