@@ -21,3 +21,12 @@ sprinter_prepend_path() {
 """
 
 source_template = """[ -r "%s" ] && . %s\n"""
+
+warning_template = """
+__          __     _____  _   _ _____ _   _  _____
+\ \        / /\   |  __ \| \ | |_   _| \ | |/ ____|
+ \ \  /\  / /  \  | |__) |  \| | | | |  \| | |  __
+  \ \/  \/ / /\ \ |  _  /| . ` | | | | . ` | | |_ |
+   \  /\  / ____ \| | \ \| |\  |_| |_| |\  | |__| |
+    \/  \/_/    \_\_|  \_\_| \_|_____|_| \_|\_____|
+"""
